@@ -240,7 +240,8 @@ class EffectProperties(gtk.Expander, gtk.HBox):
         self._showInfoBar()
         self._vcontent.show()
         self.set_expanded(True)
-        self.set_label("Effects configuration")
+        self.set_label(_("Effects"))
+        self.connect('notify::expanded', self._expandedCb)
 
     def _newProjectLoadedCb(self, app, project):
         self.clip_properties.project = project
@@ -274,6 +275,7 @@ class EffectProperties(gtk.Expander, gtk.HBox):
             for timeline_object in self.timeline_objects:
                 timeline_object.connect("track-object-added", self._trackObjectAddedCb)
                 timeline_object.connect("track-object-removed", self._trackRemovedRemovedCb)
+            self.set_sensitive(True)
         else:
             self.timeline_objects = []
             self.set_sensitive(False)
@@ -478,7 +480,7 @@ class TransformationProperties(gtk.Expander):
         self._current_tl_obj = None
         self.spin_buttons = {}
         self.default_values = {}
-        self.set_label(_("Transformation configuration"))
+        self.set_label(_("Transformation"))
         self.set_sensitive(False)
 
         if not "Frei0r" in soft_deps:
