@@ -27,8 +27,9 @@ Dialog box for project settings
 import gtk
 import gst
 import os
-from pwd import getpwuid
+
 from datetime import datetime
+
 from pitivi.configure import get_ui_dir
 from gettext import gettext as _
 from pitivi.ui.dynamic import FractionWidget
@@ -111,16 +112,7 @@ class ProjectSettingsDialog():
         self.sample_rate_combo.set_model(audio_rates)
         self.sample_depth_combo.set_model(audio_depths)
 
-        # set the project metadata
-        # FIXME: not saved in the project file
-        if self.year_spinbutton.get_value_as_int() == 1900:
-            self.year_spinbutton.set_value(datetime.now().year)
-        if self.author_entry.get_text() == "":
-            self.full_user_name = getpwuid(os.getuid()).pw_gecos.split(",")[0]
-            self.author_entry.set_text(self.full_user_name)
-
         # behavior
-
         self.wg = RippleUpdateGroup()
         self.wg.addVertex(self.frame_rate_combo,
                 signal="changed",
@@ -189,9 +181,9 @@ class ProjectSettingsDialog():
 
         # presets
         self.audio_presets = AudioPresetManager()
-        self.audio_presets.load()
+        self.audio_presets.loadAll()
         self.video_presets = VideoPresetManager()
-        self.video_presets.load()
+        self.video_presets.loadAll()
 
         self._fillPresetsTreeview(
                 self.audio_preset_treeview, self.audio_presets,
@@ -240,6 +232,9 @@ class ProjectSettingsDialog():
 
         self.updateUI()
 
+        self.createAudioNoPreset(self.audio_presets)
+        self.createVideoNoPreset(self.video_presets)
+
     def bindPar(self, mgr):
 
         def updatePar(value):
@@ -291,6 +286,21 @@ class ProjectSettingsDialog():
             mgr, update_buttons_func)
         treeview.connect("focus-out-event", self._treeviewDefocusedCb, mgr)
 
+    def createAudioNoPreset(self, mgr):
+        mgr.prependPreset(_("No preset"), {
+            "depth": int(get_combo_value(self.sample_depth_combo)),
+            "channels": int(get_combo_value(self.channels_combo)),
+            "sample-rate": int(get_combo_value(self.sample_rate_combo))})
+
+    def createVideoNoPreset(self, mgr):
+        mgr.prependPreset(_("No preset"), {
+            "par": gst.Fraction(int(get_combo_value(self.par_combo).num),
+                                    int(get_combo_value(self.par_combo).denom)),
+            "frame-rate": gst.Fraction(int(get_combo_value(self.frame_rate_combo).num),
+                            int(get_combo_value(self.frame_rate_combo).denom)),
+            "height": int(self.height_spinbutton.get_value()),
+            "width": int(self.width_spinbutton.get_value())})
+
     def _newPresetCb(self, model, path, iter_, column, renderer, treeview):
         """Handle the addition of a preset to the model of the preset manager.
         """
@@ -398,6 +408,9 @@ class ProjectSettingsDialog():
             "video-preset-infobar")
         self.audio_preset_infobar = self.builder.get_object(
             "audio-preset-infobar")
+        self.title_entry = self.builder.get_object("title_entry")
+        self.author_entry = self.builder.get_object("author_entry")
+        self.year_spinbutton = self.builder.get_object("year_spinbutton")
 
     def _constrainSarButtonToggledCb(self, button):
         if button.props.active:
@@ -415,10 +428,10 @@ class ProjectSettingsDialog():
         """Get a unique name for a new preset for the specified PresetManager.
         """
         existing_preset_names = list(mgr.getPresetNames())
-        preset_name = _("New Preset")
+        preset_name = _("New preset")
         i = 1
         while preset_name in existing_preset_names:
-            preset_name = _("New Preset %d") % i
+            preset_name = _("New preset %d") % i
             i += 1
         return preset_name
 
@@ -474,7 +487,7 @@ class ProjectSettingsDialog():
         self.save_video_preset_button.set_sensitive(preset_changed)
         preset_selected = bool(self.video_presets.cur_preset)
         self.remove_video_preset_button.set_sensitive(preset_selected)
-    
+
     def _updateAudioSaveButton(self, unused_in, button):
         button.set_sensitive(self.audio_presets.isCurrentPresetChanged())
 
@@ -537,6 +550,20 @@ class ProjectSettingsDialog():
 
         self._selectDarRadiobuttonToggledCb(self.select_dar_radiobutton)
 
+        # metadata
+        self.title_entry.set_text(self.project.name)
+        self.author_entry.set_text(self.project.author)
+        if self.project.year:
+            year = int(self.project.year)
+        else:
+            year = datetime.now().year
+        self.year_spinbutton.get_adjustment().set_value(year)
+
+    def updateMetadata(self):
+        self.project.name = self.title_entry.get_text()
+        self.project.author = self.author_entry.get_text()
+        self.project.year = str(self.year_spinbutton.get_value_as_int())
+
     def updateSettings(self):
         width = int(self.width_spinbutton.get_value())
         height = int(self.height_spinbutton.get_value())
@@ -555,6 +582,5 @@ class ProjectSettingsDialog():
     def _responseCb(self, unused_widget, response):
         if response == gtk.RESPONSE_OK:
             self.updateSettings()
-        self.audio_presets.save()
-        self.video_presets.save()
+            self.updateMetadata()
         self.window.destroy()
